@@ -1,5 +1,5 @@
 /**
- *  Copyright 2002-2023 Peter Seiderer <Peter.Seiderer@ciselant.de>
+ *  Copyright 2002-2025 Peter Seiderer <Peter.Seiderer@ciselant.de>
  *
  *  This file is part of SeBIE.
  *
@@ -22,6 +22,7 @@
 #include "sebie_helpers.h"
 #include "sebie_gtk_helpers.h"
 
+#include <errno.h>
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
@@ -306,12 +307,29 @@ on_button_save_clicked (G_GNUC_UNUSED GtkButton *button,
     }
     save = rotated;
   }
+
   GError *error = NULL;
 
-  if (gdk_pixbuf_save(save, sebie->model.output_file_name, "jpeg", &error, "quality", "85", NULL) == FALSE) {
-    sebie_error_popup(sebie, "gdb_pixbuf_save failed.");
+  size_t output_file_name_len = strlen(sebie->model.output_file_name);
+  if (output_file_name_len > 4 && !strcasecmp(&sebie->model.output_file_name[output_file_name_len - 4], ".png")) {
+    if (gdk_pixbuf_save(save, sebie->model.output_file_name, "png", &error, NULL) == FALSE) {
+      if (error != NULL) {
+        sebie_error("gdk_pixbuf_save(\"%s\", \"png\") failed - %s\n", sebie->model.output_file_name, error->message);
+      }
+      sebie_error_popup(sebie, "Call to gdb_pixbuf_save() failed (png).");
+    }
+  } else {
+    if (gdk_pixbuf_save(save, sebie->model.output_file_name, "jpeg", &error, "quality", "85", NULL) == FALSE) {
+      if (error != NULL) {
+        sebie_error("gdk_pixbuf_save(\"%s\", \"jpeg\") failed - %s\n", sebie->model.output_file_name, error->message);
+      }
+      sebie_error_popup(sebie, "Call to gdb_pixbuf_save() failed (jpeg).");
+    }
   }
 
+  if (error != NULL) {
+    g_error_free(error);
+  }
   if (save != NULL) {
     g_object_unref(save);
   }
