@@ -1,5 +1,5 @@
 /**
- *  Copyright 2002-2023 Peter Seiderer <Peter.Seiderer@ciselant.de>
+ *  Copyright 2002-2025 Peter Seiderer <Peter.Seiderer@ciselant.de>
  *
  *  This file is part of SeBIE.
  *
@@ -44,7 +44,7 @@ rotate_pixbuf(GdkPixbuf *pixbuf, sebie_rotation rotation)
                                       new_width,
                                       new_height);
 
-  guchar *orig = gdk_pixbuf_get_pixels(pixbuf);
+  const guchar *orig = gdk_pixbuf_get_pixels(pixbuf);
   guchar *rota = gdk_pixbuf_get_pixels(rotated);
 
   int width  = gdk_pixbuf_get_width(pixbuf);;
@@ -101,7 +101,7 @@ pixbuf_color_corrections(GdkPixbuf *pixbuf, double gamma, int grayscale)
     int rowstride_o = gdk_pixbuf_get_rowstride(pixbuf);
     int rowstride_c = gdk_pixbuf_get_rowstride(corrected);
     int channels = gdk_pixbuf_get_n_channels(pixbuf);
-    guchar *orig = gdk_pixbuf_get_pixels(pixbuf);
+    const guchar *orig = gdk_pixbuf_get_pixels(pixbuf);
     guchar *corr = gdk_pixbuf_get_pixels(corrected);
     int i, j;
     guchar *gamma_lut;
