@@ -1,5 +1,5 @@
 /**
- *  Copyright 2002-2023 Peter Seiderer <Peter.Seiderer@ciselant.de>
+ *  Copyright 2002-2025 Peter Seiderer <Peter.Seiderer@ciselant.de>
  *
  *  This file is part of SeBIE.
  *
@@ -47,7 +47,7 @@ sebie_error(const char *format, ...)
 void
 sebie_debug(const char *format, ...)
 {
-  char *sebie_debug;
+  const char *sebie_debug;
 
   if ((sebie_debug = getenv("SEBIE_DEBUG")) != NULL) {
     va_list ap;
